<?php
// $Id$

/**
 * @file
 *
 * Administration pages.
 */

/**
 * Define the settings form.
 *
 * @return array
 *   The form.
 */
function versus_settings() {
  module_load_include('inc', 'versus');

  $form['versus_voting_enabled'] = array(
    '#type' => 'radios',
    '#title' => t('Voting status'),
    '#default_value' => variable_get('versus_voting_enabled', 0),
    '#options' => array(t('Disabled'), t('Enabled')),
    '#description' => t('If voting is disabled, users cannot vote.  Select "Enabled" to allow it, or select "Disabled" to take it off-line.  Other modules (e.g. <a href="http://drupal.org/project/competition">Competition</a>) may (un)set this.'),
  );

  $form['versus_types_enabled'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Enabled content types'),
    '#description' => t('Select the content types whose nodes can be voted on.'),
    '#default_value' => versus_types_enabled(),
    '#options' => versus_node_get_types(),
  );

  return system_settings_form($form);
}

/**
 * Helper function that caches node types.
 *
 * This code was originally taken from _relatedlinks_node_get_types(),
 * in the Related Links module (http://drupal.org/project/relatedlinks).
 *
 * @param $keys
 *   A boolean variable that decides whether an associative array of node
 *   types is to be returned (or not).
 *
 * @return
 *   An associative or non-associative array of node types.
 */
function versus_node_get_types($keys = FALSE) {
  static $node_types = NULL, $key_array = NULL;

  // Check if there's anything in the cache.
  if (!isset($node_types)) {

    // There's nothing in the cache so we need to get content type information.
    $node_types = node_get_types('names');
    foreach ($node_types as $type => $name) {
      $node_types[$type] = check_plain($name);
    }

    // Set the list of keys.
    $key_array = array_keys($node_types);
  }

  // Either return the key list, or key/value pairs.
  return $keys ? $key_array : $node_types;
}