<?php
// $Id$

/**
 * @file
 *
 * Module pages.
 */

/**
 * Display voting options to users.
 *
 * @return
 *   The themed output.
 */
function versus_voting_options() {

  // Declare a list of options and some header info.
  $options = array();
  $instructions = t('Choose the appropriate item from the list:');

  // Present a voting option if the correct permissions exist.
  if (user_access('vote with versus')) {
    $options[] = array(
      'title' => t('Cast Votes'),
      'path' => 'versus/vote',
      'description' => t('Vote on items within a particular content type.'),
    );
  }

  // Present a link to the standings if the correct permissions exist.
  if (user_access('view versus results')) {
    $options[] = array(
      'title' => t('View Standings'),
      'path' => 'versus/standings',
      'description' => t('Look at the current standings for a particular content type.'),
    );
  }

  // Return the themed output.
  return theme('versus_voting_options', $instructions, $options);
}

/**
 * Receive a voting request.
 *
 * Either validate a voting request for a particular type, or show a list
 * of types that can voted on.
 *
 * @param $type
 *   The content type to vote on.
 * @param $competition
 *   The competition that the voting content should be part of,
 *   if the Competition module is enabled.
 * @return
 *   The content type's voting page, or a list of content type options
 *   if no valid type is provided.
 * @todo
 *   Set up a hook so that code for other modules doesn't have to be
 *   in here.  It'll keep things cleaner & nicer.
 */
function versus_vote_request($type = NULL, $competition = NULL) {
  module_load_include('inc', 'versus');
  module_load_include('inc', 'versus', 'versus.private');
  module_load_include('inc', 'competition');

  // Perform some checks for the Competition module.
  if (module_exists('competition')) {

    // Make sure that we're in a voting phase.
    if (!variable_get('versus_voting_enabled', FALSE)) {
      drupal_set_message(t('Sorry, but you can\'t vote now.  We\'re not currently in a voting phase.'), 'error');
      drupal_goto();
    }

    // Make sure that we're getting a valid competition node ID.
    if ($competition) {

      // Check for SQL injection.
      if (!db_result(db_query('SELECT COUNT(*) FROM {content_type_competition} WHERE (nid = %d)', $competition))) {
        watchdog('security', 'Detected possible SQL injection attempt.', WATCHDOG_WARNING);
        drupal_goto();
      }

      // Make sure it exists & is in the current round.
      $round = db_result(db_query('SELECT field_competition_round_value FROM {content_type_competition} WHERE nid = %d', $competition));
      if ($round != competition_round_get_current()) {
        drupal_set_message(t('You can only vote on a competition in the current round, round ' . competition_round_get_current() . '.'), 'error');
        drupal_goto();
      }
    }
    else /* !$competition */ {
      return versus_voting_competitions(competition_round_get_current());
    }
  }

  // Make sure that any provided type is valid.
  $types = versus_types_enabled();
  if (isset($types[$type])) {
    $output = versus_vote_process_type($type, $competition);
  }
  else /* no valid content type has been provided */ {
    $output = theme('versus_voting_types', $types);
  }

  return $output;
}