<?php
// $Id$

/**
 * @file
 *
 * Module themes.
 */

/**
 * Theme the general voting options.
 *
 * @param $instructions
 *   The instructions.
 * @param $options
 *   A list of  associate arrays containing the following elements:
 *     'title'       - the page title
 *     'path'        - the local Drupal path that the item links to
 *     'description' - a description of the item
 * @return
 *   The themed output as HTML.
 */
function theme_versus_voting_options($instructions, $options) {

  // Print the instructions.
  $output = "<p>$instructions</p>";

  // Present the options as a definition list.
  $output .= "<dl>";
  foreach ($options as $option) {
    $output .= "<dt>" . l($option['title'], $option['path']) . "</dt>";
    $output .= "<dd>" . $option['description'] . "</dd>";
  }
  $output .= "</dl>";

  // Return the HTML.
  return $output;
}

/**
 * Theme a display of the competitions and their content types that
 * can be voted on.
 *
 * @param $instructions
 *   The instructions.
 * @param $competitions
 *   A list of associated arrays representing competitions and their
 *   content types.  Each item contains the following elements:
 *     'nid'   - the node ID of the competition
 *     'title' - the title of the competition
 *     'types' - a list of content types accepted by the competition
 * @return
 *   The themed output as HTML.
 */
function theme_versus_voting_competitions($instructions, $competitions) {

  // Set the voting path.  Perhaps this should be an argument?
  $path = "versus/vote";

  // Print the instructions.
  $output = "<p>$instructions</p>";

  // Present the options as a definition list.
  $output .= "<dl>";
  foreach ($competitions as $competition) {

    // For each competition, we need the ID, title and types it supports.
    $nid   = $competition['nid'];
    $title = $competition['title'];
    $types = $competition['types'];

    // Display a link to each competition.
    $output .= "<dt>" . l($title, "node/$nid") . "</dt>";

    // Each definition is a list of available types.
    $output .= "<dd><ul>";
    foreach ($types as $type) {

      // Display a link for each type so that it can be voted on.
      $type_name = node_get_types('name', $type);
      $output .= "<li>" . l($type_name, "$path/$type/$nid")  . "</li>";
    }
    $output .= "</ul></dd>";
  }
  $output .= "</dl>";

  // Return the HTML.
  return $output;
}

/**
 * Theme a general voting request.
 *
 * @param $types
 *   The content types that can be voted on.
 * @return
 *   The themed output of the voting options.
 */
function theme_versus_voting_types($types) {

  // Get an overview of all content types that can be voted on.
  foreach ($types as $type => $name) {

    // Skip unset content types.
    if ((!$type) || (!$name) || ($type == 1)) {
      continue;
    }

    // Show a link for each thing that can be vored on.
    $title = t('Vote for an existing @s.', array('@s' => $name));
    $out = '<dt>'. l(
      node_get_types('name', $name),
      "versus/vote/". $type,
      array('title' => $title)
    ) .'</dt>';
    $item[$type] = $out;
  }

  // Add a title & format it.
  if (isset($item)) {
    uksort($item, 'strnatcasecmp');
    $output = t('Choose the type of content that you would like to vote on:') .
      '<dl>'. implode('', $item) .'</dl>';
  }
  else {
    $output = t('No content types available for voting.');
  }

  return $output;
}

/**
 * Theme the voting ballot.
 *
 * @param $left
 *   The node representing the choice on the left.
 * @param $right
 *   The node representing the choice on the right.
 * @return
 *   The themed output of whatever's on the voting ballot.
 */
function theme_versus_voting_ballot($left = NULL, $right = NULL) {

  // Prepare the forms for each vote
  $input_left  = drupal_get_form('versus_voting_left_form', $left->nid, $right->nid, $left->type);
  $input_right = drupal_get_form('versus_voting_right_form', $right->nid, $left->nid, $left->type);

  // Show the teaser for each node side by side.
  $output  = '<table id="versus_box_choices" width="100%" border="0" cellspacing="0" cellpadding="0">';
  $output .= '  <tr>';
  $output .= '    <td>'. node_view($left, TRUE, FALSE, FALSE) .'</td>';
  $output .= '    <td>'. node_view($right, TRUE, FALSE, FALSE) .'</td>';
  $output .= '  </tr>';
  $output .= '  <tr>';
  $output .= '    <td>'. $input_left .'</td>';
  $output .= '    <td>'. $input_right .'</td>';
  $output .= '  </tr>';
  $output .= '</table>';

  // Return the ballot for display.
  return $output;
}

/**
 * Theme a voting button.
 *
 * @param $form
 *   The associated form.
 * @return
 *   The themed button.
 */
function theme_versus_vote_button($form) {
  return '<input type="submit" class="form-submit" value="Vote" id="edit-vote-ref-1" name="op"/>';
}
